@@ -1,5 +1,5 @@
 require "test/unit"
-require_relative "core_assertions"
+require "core_assertions"
 
 Test::Unit::TestCase.include Test::Unit::CoreAssertions
 
